@@ -5,7 +5,7 @@
  
 package XML::Compile::Translate::Writer;
 use vars '$VERSION';
-$VERSION = '1.33';
+$VERSION = '1.34';
 
 use base 'XML::Compile::Translate';
 
@@ -147,14 +147,15 @@ sub makeSequence($@)
 
     if(@pairs==2)
     {   my ($take, $do) = @pairs;
-        return $do
-            if ref $do eq 'BLOCK' || ref $do eq 'ANY';
 
-        return bless sub {
-            my ($doc, $values) = @_;
-            defined $values or return;
-            $do->($doc, delete $values->{$take});
-        }, 'BLOCK';
+        return
+            ref $do eq 'ANY'   ? bless(sub { $do->(@_) }, 'BLOCK')
+          : ref $do eq 'BLOCK' ? $do
+          : bless sub {
+                my ($doc, $values) = @_;
+                defined $values or return;
+                $do->($doc, delete $values->{$take});
+            }, 'BLOCK';
     }
  
     bless sub {
